@@ -7,6 +7,7 @@ from ..Nodes.Interaction import View, Reaction, Comment
 from ..Counter import Counter
 
 import logging
+import pandas as pd
 
 
 class PostExtractor:
@@ -41,7 +42,7 @@ class PostExtractor:
         logging.info('Person feeds loaded')
 
         if feed_id := self.extractor.feed_id:
-            # if an feed_id was passed, extract only posts published in this feed
+            # if an feed_id was passed as parameter, extract only posts published in this feed
 
             logging.info(f'Extracting posts from feed {feed_id}')
 
@@ -195,118 +196,136 @@ class PostExtractor:
     async def call_info(self, url, session, **kwargs):
         data = await self.extractor.fetch_url(url, session, 'GRAPH', **kwargs)
 
-        await self.call_info_views(data.get('seen', {}), session, **kwargs)
-        await self.call_info_reactions(data.get('reactions', {}), session, **kwargs)
-        await self.call_info_comments(data.get('comments', {}), session, **kwargs)
+        if data is not None:
+            try:
+                await self.call_info_views(data.get('seen', {}), session, **kwargs)
+                await self.call_info_reactions(data.get('reactions', {}), session, **kwargs)
+                await self.call_info_comments(data.get('comments', {}), session, **kwargs)
+            except Exception as e:
+                print(1)
 
         self.counter.increment()
         print(self.counter)
 
     async def call_info_views(self, data, session, **kwargs):
 
-        if 'data' in data:
-            for item in data['data']:
-                view = View()
-                self.set_author(item, view, 'seen')
+        try:
+            if 'data' in data:
+                for item in data['data']:
+                    view = View()
+                    self.set_author(item, view, 'seen')
 
-                kwargs.get('post').seen['data'].append(view)
+                    kwargs.get('post').seen['data'].append(view)
 
-        next_page = data.get('paging', {}).get('next')
-        if next_page is not None:
-            kwargs['recursion'] += 1
+            next_page = data.get('paging', {}).get('next')
+            if next_page is not None:
+                kwargs['recursion'] += 1
 
-            new_data = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
-            await self.call_info_views(new_data, session, **kwargs)
+                new_data = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
+                if new_data is not None:
+                    await self.call_info_views(new_data, session, **kwargs)
+        except Exception as e:
+            print(1)
 
     async def call_info_reactions(self, data, session, **kwargs):
 
-        if 'data' in data:
-            for item in data['data']:
-                reaction = Reaction(item)
-                self.set_author(item, reaction, 'reactions')
+        try:
+            if 'data' in data:
+                for item in data['data']:
+                    reaction = Reaction(item)
+                    self.set_author(item, reaction, 'reactions')
 
-                kwargs.get('post').reactions['data'].append(reaction)
+                    kwargs.get('post').reactions['data'].append(reaction)
 
-        next_page = data.get('paging', {}).get('next')
-        if next_page is not None:
-            kwargs['recursion'] += 1
+            next_page = data.get('paging', {}).get('next')
+            if next_page is not None:
+                kwargs['recursion'] += 1
 
-            new_data = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
-            await self.call_info_reactions(new_data, session, **kwargs)
+                new_data = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
+                if new_data is not None:
+                    await self.call_info_reactions(new_data, session, **kwargs)
+        except Exception as e:
+            print(1)
 
     async def call_info_comments(self, data, session, **kwargs):
-        if isinstance(data, list):
-            data = {'data': data}
 
-        if 'data' in data:
-            for item in data['data']:
-                comment = Comment(item)
-                self.set_author(item, comment, 'comments')
+        try:
+            if isinstance(data, list):
+                data = {'data': data}
 
-                if item.get('reactions', {}).get('data'):
-                    data_reactions = item.get('reactions', {})
-                    while True:
-                        for item_reaction in data_reactions.get('data'):
-                            reaction = Reaction(item_reaction)
-                            self.set_author(item_reaction, reaction, 'reactions')
+            if 'data' in data:
+                for item in data['data']:
+                    comment = Comment(item)
+                    self.set_author(item, comment, 'comments')
 
-                            comment.reactions.append(reaction)
+                    if item.get('reactions', {}).get('data'):
+                        data_reactions = item.get('reactions', {})
+                        while True:
+                            for item_reaction in data_reactions.get('data'):
+                                reaction = Reaction(item_reaction)
+                                self.set_author(item_reaction, reaction, 'reactions')
 
-                        next_page = data_reactions.get('paging', {}).get('next')
-                        if next_page is not None:
-                            kwargs['recursion'] += 1
+                                comment.reactions.append(reaction)
 
-                            data_reactions = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
-                        else:
-                            break
+                            next_page = data_reactions.get('paging', {}).get('next')
+                            if next_page is not None:
+                                kwargs['recursion'] += 1
 
-                if item.get('comments', {}).get('data'):
-                    data_comments = item.get('comments', {})
-                    while True:
-                        for item_comment in data_comments.get('data'):
-                            reply = Comment(item_comment)
-                            self.set_author(item_comment, reply, 'comments')
+                                data_reactions = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
+                            else:
+                                break
 
-                            if item_comment.get('reactions', {}).get('data'):
-                                data_comment_reactions = item_comment.get('reactions', {})
-                                while True:
-                                    for item_comment_reaction in data_comment_reactions.get('data'):
-                                        reaction = Reaction(item_comment_reaction)
-                                        self.set_author(item_comment_reaction, reaction, 'reactions')
+                    if item.get('comments', {}).get('data'):
+                        data_comments = item.get('comments', {})
+                        while True:
+                            for item_comment in data_comments.get('data'):
+                                reply = Comment(item_comment)
+                                self.set_author(item_comment, reply, 'comments')
 
-                                        reply.reactions.append(reaction)
+                                if item_comment.get('reactions', {}).get('data'):
+                                    data_comment_reactions = item_comment.get('reactions', {})
+                                    while True:
+                                        for item_comment_reaction in data_comment_reactions.get('data'):
+                                            reaction = Reaction(item_comment_reaction)
+                                            self.set_author(item_comment_reaction, reaction, 'reactions')
 
-                                    next_page = data_comment_reactions.get('paging', {}).get('next')
-                                    if next_page is not None:
-                                        kwargs['recursion'] += 1
-                                        data_comment_reactions = await self.extractor.fetch_url(next_page,
-                                                                                                session,
-                                                                                                'GRAPH',
-                                                                                                **kwargs)
-                                    else:
-                                        break
+                                            reply.reactions.append(reaction)
 
-                            comment.comments.extend(reply)
+                                        next_page = data_comment_reactions.get('paging', {}).get('next')
+                                        if next_page is not None:
+                                            kwargs['recursion'] += 1
+                                            data_comment_reactions = await self.extractor.fetch_url(next_page,
+                                                                                                    session,
+                                                                                                    'GRAPH',
+                                                                                                    **kwargs)
+                                        else:
+                                            break
 
-                        next_page = data_comments.get('paging', {}).get('next')
-                        if next_page is not None:
-                            kwargs['recursion'] += 1
-                            data_comments = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
-                        else:
-                            break
+                                comment.comments.extend(reply)
 
-                kwargs.get('post').comments['data'].extend(comment)
+                            next_page = data_comments.get('paging', {}).get('next')
+                            if next_page is not None:
+                                kwargs['recursion'] += 1
+                                data_comments = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
+                            else:
+                                break
 
-        next_page = data.get('paging', {}).get('next')
-        if next_page is not None:
-            new_data = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
-            await self.call_info_comments(new_data, session, **kwargs)
+                    kwargs.get('post').comments['data'].extend(comment)
+
+            next_page = data.get('paging', {}).get('next')
+            if next_page is not None:
+                new_data = await self.extractor.fetch_url(next_page, session, 'GRAPH', **kwargs)
+                if new_data is not None:
+                    await self.call_info_comments(new_data, session, **kwargs)
+        except Exception as e:
+            print(1)
 
     async def call_bot(self, url, session, **kwargs):
         data = await self.extractor.fetch_url(url, session, 'GRAPH', **kwargs)
 
-        if data:
-            kwargs.get('post').author = Bot(data)
+        if not isinstance(data, pd.DataFrame):
+            if data:
+                kwargs.get('post').author = Bot(data)
 
         self.counter.increment()
         print(self.counter)
